Type: Package
Package: fluxtools
Title: A 'shiny' App for Reproducible QA/QC of Eddy Covariance Data
Version: 0.7.1
Authors@R: 
    person("Kesondra", "Key", , "keyke@iu.edu", role = c("aut", "cre"))
Description: An interactive 'shiny'-based tool for exploration and quality
    assurance and quality control (QA/QC) of eddy covariance flux tower
    data processing. It generates data-point removal code via
    user-directed selection from a scatterplot, and can export a cleaned
    .csv with removed points set to NA plus an R script for
    reproducibility. Reference: Key (2025) <DOI:10.5281/zenodo.15597159>.
License: GPL-3
URL: https://github.com/kesondrakey/fluxtools,
        https://doi.org/10.5281/zenodo.15597159
BugReports: https://github.com/kesondrakey/fluxtools/issues
Depends: R (>= 4.1.0)
Imports: dplyr, plotly, readr, shiny, tibble
Suggests: kableExtra, knitr, rmarkdown, shinyWidgets, testthat (>=
        3.0.0)
VignetteBuilder: knitr
BuildVignettes: TRUE
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-09-19 01:00:34 UTC; Karmic Dreamwork
Author: Kesondra Key [aut, cre]
Maintainer: Kesondra Key <keyke@iu.edu>
Repository: CRAN
Date/Publication: 2025-10-01 16:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 18:21:27 UTC; unix
